summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete')
-rw-r--r--kopete/libkopete/kabcpersistence.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/kabcpersistence.cpp b/kopete/libkopete/kabcpersistence.cpp
index c6356d65..83caeb29 100644
--- a/kopete/libkopete/kabcpersistence.cpp
+++ b/kopete/libkopete/kabcpersistence.cpp
@@ -209,7 +209,7 @@ void KABCPersistence::slotWriteAddressBook()
void KABCPersistence::removeKABC( MetaContact *)
{
/* // remove any data this KMC has written to the KDE address book
// Save any changes in each contact's addressBookFields to KABC
KABC::AddressBook* ab = addressBook();
@@ -292,7 +292,7 @@ bool KABCPersistence::syncWithKABC( MetaContact * mc )
{
KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Sorry,
i18n( "<qt>\"%1\" is not supported by Kopete.</qt>" ).arg( protocolName ),
- i18n( "Could Not Sync with KDE Address Book" ) );
+ i18n( "Could Not Sync with TDE Address Book" ) );
continue;
}
@@ -209,7 +209,7 @@ void KABCPersistence::slotWriteAddressBook()
void KABCPersistence::removeKABC( MetaContact *)
{
-/* // remove any data this KMC has written to the KDE address book
+/* // remove any data this KMC has written to the TDE address book
// Save any changes in each contact's addressBookFields to KABC
KABC::AddressBook* ab = addressBook();